@@ -8,17 +8,20 @@ getAllResources = function(microbeNames) {
     # read in all the microbe files and get the full list of resources needed
     
     allResources = NULL
-    ct = 0
+
     for (gname in microbeNames) {
         data = get(gname)
         nres = colnames(data)
-        nres = nres[nres != "units" & nres != "Biomass" & nres != "biomass" & nres != 
-            "Units"]
-        allResources = append(allResources, nres, after = ct)
-        ct = ct + length(colnames(data))
+        for (i in 1:length(nres)){
+            if (!is.na(data['Rtype',i]) & nres[i] != "units"  & nres[i] != "Units" &
+                nres[i] != "Biomass" & nres[i] != "biomass" ){
+                allResources=c(allResources,nres[i])
+            }
+        }
     }
     
     resNames = unique(allResources[!is.na(allResources)])
     
     return(resNames)
+    
 }
